mix library

/\\ /\\ /\\\\\\ /\\ /\
/\\\ /\\\ /////\/// ///\\ /\/ /\//\\ /\//\\ /\\ ///\\\/ /\\///\/\/ /\\ /\\ //\\ /\\ ///\/ /\\ /\\ /\\ /\\ /// /\\ /\\ /\\\ /\\ /\\ /\\ /\////\
/\\ /\\ /\\\\\\ /\/ ///\
/// /// /////////// /// ///

                   https://fluttermix.com

        /\///////////////////////////////////////////////////\
        \/\           ***** GENERATED CODE *****            \ \
         \/\            ** DO NOT EDIT THIS FILE **          \ \
          \/\             Generated with barrel script        \ \
           \/////////////////////////////////////////////////////

Classes

AbsNumberDirective
Returns the absolute value of a numeric value.
AddNumberDirective
Adds a value to a numeric value.
AlignmentDirectionalRef
Token reference for AlignmentDirectional values
AlignmentGeometryRef
Token reference for AlignmentGeometry values
AlignmentRef
Token reference for Alignment values
AlignModifier
Modifier that aligns its child within the available space.
AlignModifierMix
Mix class for applying alignment modifications.
AlphaColorDirective
Directive that applies alpha to a color.
AnimationConfig
Configuration data for animated styles in the Mix framework.
AspectRatioModifier
Modifier that constrains its child to a specific aspect ratio.
AspectRatioModifierMix
Mix class for applying aspect ratio modifications.
BaseShadowMix<T extends Shadow>
Base class for shadow styling.
BeveledRectangleBorderMix
Mix-compatible representation of Flutter's BeveledRectangleBorder with beveled corners.
BlurModifier
Modifier that applies a Gaussian blur filter to its child.
BlurModifierMix
Mix class for applying blur modifications.
BorderConverter
Converts Border to BorderMix.
BorderDirectionalMix
Mix-compatible representation of Flutter's BorderDirectional with RTL support.
BorderMix
Mix representation of Border.
BorderRadiusConverter
Converts BorderRadius to BorderRadiusMix.
BorderRadiusDirectionalMix
Mix representation of BorderRadiusDirectional.
BorderRadiusDirectionalRef
Token reference for BorderRadiusDirectional values
BorderRadiusGeometryConverter
Converts BorderRadiusGeometry to BorderRadiusMix.
BorderRadiusGeometryMix<T extends BorderRadiusGeometry>
Base class for Mix border radius types.
BorderRadiusGeometryRef
Token reference for BorderRadiusGeometry values
BorderRadiusMix
Mix representation of BorderRadius.
BorderRadiusRef
Token reference for BorderRadius values
BorderSideConverter
Converts BorderSide to BorderSideMix.
BorderSideMix
Mix-compatible representation of Flutter's BorderSide for individual border styling.
BorderSideRef
Token reference for BorderSide values.
BorderSideToken
Design token for BorderSide values.
Box
Box is equivalent to Flutter's Container, it provides styling capabilities through the Mix framework. It can be used to create visually styled boxes with decoration, padding, margins, transforms, and constraints.
BoxBorderMix<T extends BoxBorder>
Base class for Mix border types.
BoxBorderRef
Token reference for BoxBorder values
BoxConstraintsConverter
Converts BoxConstraints to BoxConstraintsMix.
BoxConstraintsMix
Mix representation of BoxConstraints.
BoxConstraintsRef
Token reference for BoxConstraints values
BoxDecorationConverter
Converts BoxDecoration to BoxDecorationMix.
BoxDecorationMix
Mix representation of BoxDecoration.
BoxDecorationRef
Token reference for BoxDecoration values
BoxModifier
Modifier that wraps its child in a styled Container using BoxSpec styling.
BoxModifierMix
Mix class for applying box (Container) modifications.
BoxShadowConverter
Converts BoxShadow to BoxShadowMix.
BoxShadowListMix
Mix wrapper for a list of BoxShadowMix items resolving to List<BoxShadow>.
BoxShadowListMixRef
Token reference for BoxShadowListMix that implements Mix interface instead of Flutter interface
BoxShadowListRef
Token reference for List<BoxShadow> values
BoxShadowMix
Mix representation of BoxShadow.
BoxShadowMixRef
Token reference for BoxShadowMix that implements Mix interface instead of Flutter interface
BoxShadowRef
Token reference for BoxShadow values
BoxShadowToken
Design token for box shadow lists.
BoxSpec
Specification for box styling and layout properties.
BoxStyler
Style class for configuring BoxSpec properties.
Breakpoint
Represents a responsive breakpoint for screen size-based styling.
BreakpointRef
Token reference for Breakpoint values
BreakpointToken
Design token for Breakpoint values.
BrightenColorDirective
Directive that brightens a color.
CapitalizeStringDirective
Directive that capitalizes the first letter of a string.
CeilNumberDirective
Ceils a numeric value (rounds up).
CircleBorderMix
Mix representation of CircleBorder.
ClampNumberDirective
Clamps a numeric value between min and max bounds.
ClipOvalModifier
Modifier that clips its child to an oval shape.
ClipOvalModifierMix
Mix class for applying clip oval modifications.
ClipPathModifier
Modifier that clips its child using a custom path.
ClipPathModifierMix
Mix class for applying clip path modifications.
ClipRectModifier
Modifier that clips its child to a rectangular shape.
ClipRectModifierMix
Mix class for applying clip rect modifications.
ClipRRectModifier
Modifier that clips its child to a rounded rectangular shape.
ClipRRectModifierMix
Mix class for applying clip rounded rect modifications.
ClipTriangleModifier
Modifier that clips its child to a triangle shape.
ClipTriangleModifierMix
Mix class for applying clip triangle modifications.
ColorRef
Token reference for Color values with directive support.
ColorToken
Design token for Color values.
ColumnBox
Vertical flex box with Mix styling.
ConstraintsMix<T extends Constraints>
Base class for Mix constraint types.
ContextVariant
Variants that automatically apply based on context conditions.
ContextVariantBuilder<S extends Style<Object?>>
Variant that dynamically builds a Style based on build context.
ContinuousRectangleBorderMix
Mix-compatible representation of Flutter's ContinuousRectangleBorder with smooth curved corners.
ConversionContext
Provides context for type conversion operations.
CurveAnimationConfig
Curve-based animation configuration with fixed duration.
CurveAnimationDriver<S extends Spec<S>>
A driver for curve-based animations with fixed duration.
CurveRef
Token reference for Curve values
DarkenColorDirective
Directive that darkens a color.
DecorationConverter
Converts Decoration to its corresponding Mix type.
DecorationImageMix
Mix representation of DecorationImage.
DecorationImageRef
Token reference for DecorationImage values
DecorationMix<T extends Decoration>
Base class for decoration styling.
DefaultTextStyleModifier
Modifier that applies default text styling to its descendants.
DefaultTextStyleModifierMix
Mix class for applying default text style modifications.
DefaultTextStylerModifier
Modifier that propagates a TextStyler to descendant StyledText widgets.
DefaultTextStylerModifierMix
Mix class for DefaultTextStylerModifier.
DesaturateColorDirective
Directive that desaturates a color.
Directive<T>
Base class for directives that apply transformations to values.
DivideNumberDirective
Divides a numeric value by a divisor.
DoubleToken
Design token for general double values.
DurationRef
Token reference for Duration values
DurationToken
Design token for Duration values.
EdgeInsetsConverter
Converts EdgeInsets to EdgeInsetsMix.
EdgeInsetsDirectionalMix
Mix representation of EdgeInsetsDirectional.
EdgeInsetsDirectionalRef
Token reference for EdgeInsetsDirectional values
EdgeInsetsGeometryConverter
Converts EdgeInsetsGeometry to its corresponding Mix type.
EdgeInsetsGeometryMix<T extends EdgeInsetsGeometry>
Base class for Mix edge insets types.
EdgeInsetsGeometryRef
Token reference for EdgeInsetsGeometry values
EdgeInsetsMix
Mix representation of EdgeInsets.
EdgeInsetsRef
Token reference for EdgeInsets values
FlexBox
FlexBox combines Flutter's Container and Flex widgets with Mix styling.
FlexBoxSpec
Specification that combines box styling and flex layout properties.
FlexBoxStyler
Represents the attributes of a FlexBoxSpec.
FlexibleModifier
Modifier that makes its child flexible within a flex layout.
FlexibleModifierMix
Mix class for applying flexible modifications.
FlexSpec
Defines the styling for a Flex widget.
FlexStyler
Represents the attributes of a FlexSpec.
FloorNumberDirective
Floors a numeric value (rounds down).
FontFeatureRef
Token reference for FontFeature values
FontWeightRef
Token reference for FontWeight values
FontWeightToken
Design token for FontWeight values.
FractionallySizedBoxModifier
Modifier that sizes its child to a fraction of the available space.
FractionallySizedBoxModifierMix
Mix class for applying fractionally sized box modifications.
FunctionMixConverter<T>
A converter that delegates to a function.
GradientConverter
Converts Gradient to its corresponding Mix type.
GradientMix<T extends Gradient>
Base class for gradient styling.
GradientRef
Token reference for Gradient values
GradientTransformRef
Token reference for GradientTransform values
IconScope
Provides icon styling context to descendant widgets.
IconSpec
Specification for icon styling properties.
IconStyler
IconThemeModifier
Modifier that applies icon theme data to its descendants.
IconThemeModifierMix
Represents the attributes of a IconThemeModifier.
ImageProviderRef
Token reference for ImageProvider values
ImageSpec
Specification for image styling properties.
ImageStyler
ImplicitAnimationDriver<S extends Spec<S>, C extends AnimationConfig>
IntrinsicHeightModifier
Modifier that forces its child to be exactly as tall as its intrinsic height.
IntrinsicHeightModifierMix
Represents the attributes of a IntrinsicHeightModifier.
IntrinsicWidthModifier
Modifier that forces its child to be exactly as wide as its intrinsic width.
IntrinsicWidthModifierMix
Represents the attributes of a IntrinsicWidthModifier.
Keyframe<T>
KeyframeAnimationConfig<S extends Spec<S>>
KeyframeAnimationDriver<S extends Spec<S>>
A driver for keyframe-based animations with complex timeline control.
KeyframeAnimationResult
KeyframeTrack<T>
LightenColorDirective
Directive that lightens a color.
LinearBorderEdgeMix
Mix-compatible representation of LinearBorderEdge with size and alignment properties.
LinearBorderMix
Mix-compatible representation of Flutter's LinearBorder with configurable edge styling.
LinearGradientConverter
Converts LinearGradient to LinearGradientMix.
LinearGradientMix
Mix representation of LinearGradient.
LinearGradientRef
Token reference for LinearGradient values.
LocaleRef
Token reference for Locale values
LowercaseStringDirective
Directive that converts a string to lowercase.
MaterialTokens
Provides access to Material Design tokens for colors and text styles.
Matrix4Ref
Token reference for Matrix4 values
Mix<T>
Base class for Mix-compatible styling elements that are both mixable and resolvable.
Mixable<T>
Base class for types that can be merged together.
MixColors
A class that defines a comprehensive set of colors and color swatches for the Mix framework.
MixConverter<T>
Defines how to convert values to their Mix representations.
MixConverterRegistry
A singleton registry for type converters.
MixOps
Core operations for Mix framework value transformations.
MixScope
Provides Mix design tokens and configuration to descendant widgets.
MixSource<V>
A source that contains a Mix value.
MixStyler<ST extends Style<SP>, SP extends Spec<SP>>
MixToken<T>
A design token that resolves to a value within a Mix theme.
ModifierListTween
ModifierMix<S extends WidgetModifier<S>>
MouseCursorModifier
Modifier that applies a mouse cursor to its child.
MouseCursorModifierMix
Represents the attributes of a MouseCursorModifier.
MultiplyNumberDirective
Multiplies a numeric value by a factor.
NamedVariant
Manual variants applied when explicitly requested.
NoAnimationDriver<S extends Spec<S>>
A driver that bypasses all animation and immediately applies spec changes.
NumberDirective
Base class for number directives that transform numeric values.
OffsetRef
Token reference for Offset values
OpacityColorDirective
Directive that applies opacity to a color.
OpacityModifier
Modifier that applies opacity to its child.
OpacityModifierMix
Mix class for applying opacity modifications.
OutlinedBorderMix<T extends OutlinedBorder>
Base class for outlined shape borders.
PaddingModifier
Modifier that adds padding around its child.
PaddingModifierMix
Mix class for applying padding modifications.
PhaseAnimationConfig<T extends Spec<T>, U extends Style<T>>
PhaseAnimationDriver<S extends Spec<S>>
A driver for multi-phase animations that cycle through multiple specs.
PointerPosition
Data class for pointer position information.
PointerPositionNotifier
Notifier that tracks cursor position with automatic listener detection.
PointerPositionProvider
Internal provider for cursor position tracking.
Pressable
Base widget for handling press gestures and states.
PressableBox
Combines Box styling with gesture handling.
PressableWidgetState
Prop<V>
A property that can hold values, tokens, or Mix types.
PropOps
Operations for Prop merge and resolution logic.
PropSource<V>
Represents the origin of a property value.
RadialGradientConverter
Converts RadialGradient to RadialGradientMix.
RadialGradientMix
Mix representation of RadialGradient.
RadialGradientRef
Token reference for RadialGradient values.
RadiusRef
Token reference for Radius values
RadiusToken
Design token for Radius values.
RectRef
Token reference for Rect values
ResetModifier
A modifier specification that resets the style context.
ResetModifierMix
An attribute that resets the modifier context.
RotatedBoxModifier
Modifier that rotates its child by quarter turns.
RotatedBoxModifierMix
Mix class for applying rotated box modifications.
RotateModifier
RotateModifierMix
ModifierMix for rotation transform (around Z axis).
RoundedRectangleBorderMix
Mix representation of RoundedRectangleBorder.
RoundedSuperellipseBorderMix
Mix-compatible representation of Flutter's RoundedSuperellipseBorder with smoother corners.
RoundNumberDirective
Rounds a numeric value to the nearest integer (as double).
RowBox
Horizontal flex box with Mix styling.
SaturateColorDirective
Directive that saturates a color.
ScaleModifier
ScaleModifierMix
Mix class for applying scale transform modifications.
ScrollViewModifier
Modifier that applies scroll view properties to its child.
ScrollViewModifierMix
SentenceCaseStringDirective
Directive that converts a string to sentence case.
ShadeColorDirective
Directive that applies shade to a color.
ShaderCallbackBuilder
Utility class for common Shader Function(Rect) callbacks.
ShaderMaskModifier
Modifier that applies a shader mask to its child.
ShaderMaskModifierMix
Mix class for applying shader mask modifications.
ShadowConverter
Converts Shadow to ShadowMix.
ShadowListMix
Mix wrapper for a list of ShadowMix items resolving to List<Shadow>.
ShadowListMixRef
Token reference for ShadowListMix that implements Mix interface instead of Flutter interface
ShadowListRef
Token reference for List<Shadow> values
ShadowMix
Mix representation of Shadow.
ShadowMixRef
Token reference for ShadowMix that implements Mix interface instead of Flutter interface
ShadowRef
Token reference for Shadow values
ShadowToken
Design token for shadow lists.
ShapeBorderConverter
Converts ShapeBorder to its corresponding Mix type.
ShapeBorderMix<T extends ShapeBorder>
Base class for Mix shape border types.
ShapeBorderRef
Token reference for ShapeBorder values
ShapeDecorationMix
Mix-compatible representation of Flutter's ShapeDecoration with custom shape support.
SimpleMixConverter<T>
A converter for types that don't require nested conversions.
SizedBoxModifier
Modifier that constrains its child to a specific size.
SizedBoxModifierMix
Mix class for applying sized box modifications.
SkewModifier
SkewModifierMix
ModifierMix for skew transform.
SpaceToken
Design token for spacing values.
Spec<T extends Spec<T>>
Base class for all resolved specifications that define widget properties.
SpecTween<T extends Spec<T>>
A Tween for interpolating between two Spec objects.
SpringAnimationConfig
Spring-based animation configuration for physics-based animations.
SpringAnimationDriver<S extends Spec<S>>
A driver for spring-based physics animations.
SpringCurve
A curve that uses a spring simulation to animate.
StackBox
StackBox is equivalent to Flutter's Stack and Container widgets combined, but provides powerful styling capabilities through the Mix framework.
StackBoxSpec
Specification that combines box styling and stack layout properties.
StackBoxStyler
Represents the attributes of a StackBoxSpec.
StackMix
Mix class for configuring StackSpec properties.
StackSpec
Specification for stack layout properties.
StackStyler
Represents the attributes of a StackSpec.
StadiumBorderMix
Mix-compatible representation of Flutter's StadiumBorder with rounded stadium shape.
StarBorderMix
Mix representation of StarBorder.
StrutStyleConverter
Converts StrutStyle to StrutStyleMix.
StrutStyleMix
Mix representation of StrutStyle.
StrutStyleRef
Token reference for StrutStyle values
Style<S extends Spec<S>>
Base class for style classes that can be resolved to specifications.
StyleAnimationBuilder<S extends Spec<S>>
A widget that handles animation of styles using an AnimationDriver.
StyleAnimationDriver<S extends Spec<S>>
Base class for animation drivers that handle style interpolation.
StyleBuilder<S extends Spec<S>>
Builds widgets with Mix styling.
StyledIcon
StyledIcon is equivalent to Flutter's Icon widget, but provides styling capabilities through the Mix framework. It allows you to create visually styled icons with color, size, shadows, and responsive variants.
StyledImage
StyledImage is equivalent to Flutter's Image widget, but provides styling capabilities through the Mix framework. It allows you to create visually styled images with dimensions, colors, blend modes, filters, and responsive variants.
StyledText
StyledText is equivalent to Flutter's Text widget, but provides styling capabilities through the Mix framework. It allows you to create visually styled text with typography, colors, decorations, text transformations, and responsive variants.
StyleProvider<S extends Spec<S>>
Provides unresolved styles to descendant widgets for inheritance.
StyleSpec<T extends Spec<T>>
A widget specification that wraps a pure Spec with widget metadata.
StyleSpecBuilder<S extends Spec<S>>
Builds widgets with resolved style specifications.
StyleSpecProvider<T extends Spec<T>>
Provides a resolved StyleSpec to descendant widgets.
StyleVariation<S extends Spec<S>>
Interface for design system components that adapt their styling based on active variants and user modifications.
StyleWidget<S extends Spec<S>>
Base widget for applying Mix styles to Flutter widgets.
SubtractNumberDirective
Subtracts a value from a numeric value.
SweepGradientConverter
Converts SweepGradient to SweepGradientMix.
SweepGradientMix
Mix representation of SweepGradient.
SweepGradientRef
Token reference for SweepGradient values.
TableBorderRef
Token reference for TableBorder values
TableColumnWidthRef
Token reference for TableColumnWidth values
TextDecorationRef
Token reference for TextDecoration values
TextHeightBehaviorConverter
Converts TextHeightBehavior to TextHeightBehaviorMix.
TextHeightBehaviorMix
Mix representation of TextHeightBehavior.
TextHeightBehaviorRef
Token reference for TextHeightBehavior values
TextScalerRef
Token reference for TextScaler values
TextScope
Provides text styling context to descendant widgets.
TextSpec
Specification for text styling and layout properties.
TextStyleConverter
Converts TextStyle to TextStyleMix.
TextStyleMix
Mix representation of TextStyle.
TextStyleMixRef
Token reference for TextStyleMix that implements Mix interface instead of Flutter interface
TextStyler
Represents the attributes of a TextSpec.
TextStyleRef
Token reference for TextStyle values
TextStyleToken
Design token for TextStyle values.
TintColorDirective
Directive that applies tint to a color.
TitleCaseStringDirective
Directive that converts a string to title case.
TokenSource<V>
A source that references a token.
TransformModifier
Modifier that applies matrix transformations to its child.
TransformModifierMix
Mix class for applying transform modifications.
TranslateModifier
TranslateModifierMix
ModifierMix for translation transform.
TriangleClipper
UppercaseStringDirective
Directive that converts a string to uppercase.
ValueSource<V>
A source that holds a direct value.
Variant
Base class for all variant types.
VariantStyle<S extends Spec<S>>
Variant wrapper for conditional styling
VisibilityModifier
Modifier that controls the visibility of its child.
VisibilityModifierMix
Mix class for applying visibility modifications.
WidgetModifier<Self extends WidgetModifier<Self>>
Unified base class for widget modifiers.
WidgetModifierConfig
Configuration for widget modifiers in the Mix framework.
WidgetStateProvider
Provider for widget state information using Flutter's InheritedModel.
WidgetStateVariant
WithBlueColorDirective
Directive that sets the blue channel of a color.
WithGreenColorDirective
Directive that sets the green channel of a color.
WithRedColorDirective
Directive that sets the red channel of a color.
WithValuesColorDirective
Directive that applies withValues to a color.

Enums

ElevationShadow
Material Design elevation levels.
ListMergeStrategy
Merge strategy for lists

Mixins

AnimationStyleMixin<T extends Style<S>, S extends Spec<S>>
BorderRadiusStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient border radius styling methods
BorderStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient border styling methods
ConstraintStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient constraint styling methods for styles
DecorationStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient decoration styling methods
DefaultValue<Value>
Mixin for types that have default values.
EnumVariant
Mixin for enums that act as NamedVariants.
FlexStyleMixin<T extends Mix<Object?>>
Provides convenient flex layout styling methods for spec attributes.
Resolvable<V>
Mixin for types that can be resolved to a value using a BuildContext.
ShadowStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient shadow styling methods
SpacingStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient spacing styling methods for styles
TextStyleMixin<T extends Mix<Object?>>
Provides convenient text styling methods for spec attributes.
TransformStyleMixin<T extends Mix<Object?>>
Mixin that provides convenient transform styling methods for styles
ValueRef<T>
VariantStyleMixin<T extends Style<S>, S extends Spec<S>>
Mixin that provides convenient variant styling methods for spec attributes.
WidgetModifierStyleMixin<T extends Style<S>, S extends Spec<S>>
Provides convenient widget modifier styling methods for spec attributes.
WidgetStateVariantMixin<T extends Style<S>, S extends Spec<S>>
Mixin that provides widget state variant styling methods for spec attributes.

Extension Types

DoubleRef
Token reference for double values that implements the double interface.

Extensions

DirectiveListExt on List<Directive<T>>
Extension on List<Directive<T>> to provide apply functionality
DurationIntExt on int
Extension on int to create Duration objects with convenient syntax.
NumberPropDirectiveExt on Prop<T>
Extension on Prop for number transformations.
StyleSpecWidgetBuilder on StyleSpec<T>
Extension to create widgets from StyleSpec using custom builder functions.
WidgetStateControllerExtension on WidgetStatesController
Extension on WidgetStatesController providing convenient setters and getters for individual widget states.

Constants

danger → const NamedVariant
large → const NamedVariant
outlined → const NamedVariant
primary → const NamedVariant
secondary → const NamedVariant
small → const NamedVariant
solid → const NamedVariant

Properties

defaultModifier Map<Type, Object>
final

Functions

areMixConvertersInitialized() bool
Checks whether the built-in converters have been registered.
assertIsRealType(Type value) → void
Asserts that the given type is not a token reference type.
clearTokenRegistry() → void
Clears the token registry.
createMaterialMixScope({Map<MixToken, Object>? additionalTokens, List<Type>? orderOfModifiers, required Widget child, Key? key}) Widget
Creates a MixScope with Material Design tokens pre-configured.
getReferenceValue<T>(MixToken<T> token) → T
Creates the appropriate token reference for the given token.
getTokenFromValue<T>(Object value) MixToken<T>?
Returns the token associated with a token reference value.
hasAllVariants(List<NamedVariant> activeVariants, List<NamedVariant> variants) bool
hasAnyVariant(List<NamedVariant> activeVariants, List<NamedVariant> variants) bool
hasVariant(List<NamedVariant> activeVariants, NamedVariant variant) bool
initializeMixConverters() → void
Registers all built-in converters for Flutter types.
isAnyTokenRef(Object value) bool
Returns true if the value is a token reference.
provideCursorPosition({Key? key, required PointerPositionNotifier notifier, required Widget child}) Widget
Helper function to create a cursor position provider.

Typedefs

DefaultStyledIcon = StyleProvider<IconSpec>
Provides IconStyler to descendant StyledIcon widgets.
DefaultStyledText = StyleProvider<TextSpec>
Provides TextStyler to descendant StyledText.
KeyframeStyleBuilder<T extends Spec<T>, U extends Style<T>> = U Function(KeyframeAnimationResult result, U style)
TweenBuilder<T> = Tween<T> Function({T? begin, T? end})