BorderRadiusGeometryConverter class

Converts BorderRadiusGeometry to BorderRadiusMix.

Currently supports BorderRadius. Other BorderRadiusGeometry types will throw UnimplementedError.

Implemented types

Constructors

BorderRadiusGeometryConverter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMix(BorderRadiusGeometry value, ConversionContext context) Mix<BorderRadiusGeometry>
Converts a value to its Mix representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited