BorderSideToken class

Design token for BorderSide values.

Inheritance

Constructors

BorderSideToken(String name)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() BorderSideRef
Returns a reference value for Mix utilities.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) BorderSide
Resolves this token to a concrete value.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited