BoxShadowMix class

Mix representation of BoxShadow.

Extends ShadowMix with spread radius support.

Inheritance
Mixed-in types
Implementers
Annotations
  • @mixable

Constructors

BoxShadowMix({Color? color, Offset? offset, double? blurRadius, double? spreadRadius})
BoxShadowMix.blurRadius(double value)
Creates a box shadow with the specified blur radius.
factory
BoxShadowMix.color(Color value)
Creates a box shadow with the specified color.
factory
BoxShadowMix.create({Prop<Color>? color, Prop<Offset>? offset, Prop<double>? blurRadius, Prop<double>? spreadRadius})
const
BoxShadowMix.offset(Offset value)
Creates a box shadow with the specified offset.
factory
BoxShadowMix.spreadRadius(double value)
Creates a box shadow with the specified spread radius.
factory
BoxShadowMix.value(BoxShadow boxShadow)
Creates a BoxShadowMix from an existing BoxShadow.

Properties

$blurRadius Prop<double>?
no setterinherited
$color Prop<Color>?
no setterinherited
$offset Prop<Offset>?
no setterinherited
$spreadRadius Prop<double>?
final
defaultValue BoxShadow
The default value to use when no explicit value is available.
no setteroverride
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

blurRadius(double value) BoxShadowMix
Copy with blur radius.
color(Color value) BoxShadowMix
Copy with color.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant BoxShadowMix? other) BoxShadowMix
Merges with another BoxShadowMix.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset({double? x, double? y}) BoxShadowMix
Copy with offset.
resolve(BuildContext context) BoxShadow
Resolves to BoxShadow using context.
inherited
spreadRadius(double value) BoxShadowMix
Returns a copy with the specified spread radius.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited

Static Methods

fromElevation(ElevationShadow value) List<BoxShadowMix>
Creates shadows from elevation level.
maybeValue(BoxShadow? boxShadow) BoxShadowMix?
Creates a BoxShadowMix from a nullable BoxShadow.