Directive<T> class abstract

Base class for directives that apply transformations to values.

Directives provide a way to transform values like colors or strings in a consistent, composable manner throughout the Mix framework.

Implementers
Annotations

Constructors

Directive()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The unique identifier for this directive type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(T value) → T
Applies the transformation to the given value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited