DurationRef class final

Token reference for Duration values

Inheritance
Implemented types
Mixed-in types

Constructors

DurationRef(Prop<Duration> prop)

Properties

$directives List<Directive<Duration>>?
Optional directives to transform the resolved value.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
Whether this property contains at least one token source.
no setterinherited
hasValue bool
Whether this property contains at least one value source.
no setterinherited
inDays int
The number of entire days spanned by this Duration.
no setterinherited
inHours int
The number of entire hours spanned by this Duration.
no setterinherited
inMicroseconds int
The number of whole microseconds spanned by this Duration.
no setterinherited
inMilliseconds int
The number of whole milliseconds spanned by this Duration.
no setterinherited
inMinutes int
The number of whole minutes spanned by this Duration.
no setterinherited
inSeconds int
The number of whole seconds spanned by this Duration.
no setterinherited
isNegative bool
Whether this Duration is negative.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<PropSource<Duration>>
The list of sources that provide values for this property.
finalinherited
type Type
The runtime type of the property's value.
no setterinherited

Methods

abs() Duration
Creates a new Duration representing the absolute length of this Duration.
inherited
compareTo(Duration other) int
Compares this Duration to other, returning zero if the values are equal.
inherited
directives(List<Directive<Duration>> directives) Prop<Duration>
Returns a new property with the given directives merged with existing ones.
inherited
mergeProp(covariant Prop<Duration>? other) Prop<Duration>
Merges this property with another property.
inherited
noSuchMethod(Invocation invocation) → Never
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(num factor) Duration
Multiplies this Duration by the given factor and returns the result as a new Duration object.
inherited
operator +(Duration other) Duration
Adds this Duration and other and returns the sum as a new Duration object.
inherited
operator -(Duration other) Duration
Subtracts other from this Duration and returns the difference as a new Duration object.
inherited
operator <(Duration other) bool
Whether this Duration is shorter than other.
inherited
operator <=(Duration other) bool
Whether this Duration is shorter than or equal to other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(Duration other) bool
Whether this Duration is longer than other.
inherited
operator >=(Duration other) bool
Whether this Duration is longer than or equal to other.
inherited
operator unary-() Duration
Creates a new Duration with the opposite direction of this Duration.
inherited
operator ~/(int quotient) Duration
Divides this Duration by the given quotient and returns the truncated result as a new Duration object.
inherited