FontWeightRef class final

Token reference for FontWeight values

Inheritance
Implemented types
Mixed-in types

Constructors

FontWeightRef(Prop<FontWeight> prop)

Properties

$directives List<Directive<FontWeight>>?
Optional directives to transform the resolved value.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
Whether this property contains at least one token source.
no setterinherited
hasValue bool
Whether this property contains at least one value source.
no setterinherited
index int
The encoded integer value of this font weight.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<PropSource<FontWeight>>
The list of sources that provide values for this property.
finalinherited
type Type
The runtime type of the property's value.
no setterinherited
value int
The thickness value of this font weight.
finalinherited

Methods

directives(List<Directive<FontWeight>> directives) Prop<FontWeight>
Returns a new property with the given directives merged with existing ones.
inherited
mergeProp(covariant Prop<FontWeight>? other) Prop<FontWeight>
Merges this property with another property.
inherited
noSuchMethod(Invocation invocation) → Never
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited