FunctionMixConverter<T> class
A converter that delegates to a function.
Use this to adapt existing conversion functions to the MixConverter interface.
- Implemented types
-
- MixConverter<
T>
- MixConverter<
Constructors
-
FunctionMixConverter(Mix<
T> _toMix(T value, ConversionContext context)) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMix(
T value, ConversionContext context) → Mix< T> -
Converts a value to its Mix representation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited