autoRows method
Sets the track repeated for each row required beyond explicit rows.
Use GridTrack.auto for unknown content height. Omit this method to get the same default on implicit rows.
Implementation
GridBoxStyler autoRows(GridTrack value) =>
merge(GridBoxStyler(autoRows: value));