IconThemeModifier class final

Modifier that applies icon theme data to its descendants.

Wraps the child in an IconTheme widget with the specified theme data.

Inheritance
Mixed-in types

Constructors

IconThemeModifier({IconThemeData data = const IconThemeData()})
const

Properties

data IconThemeData
final
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
props List<Object?>
The list of properties that constitute the state of this IconThemeModifier.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited
type Type
no setterinherited

Methods

build(Widget child) Widget
Builds the modified widget by wrapping or transforming child.
override
copyWith({IconThemeData? data}) IconThemeModifier
Creates a copy of this spec with the given fields replaced by the non-null parameter values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
lerp(covariant IconThemeModifier? other, double t) IconThemeModifier
Linearly interpolates with another Spec object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited