IntrinsicHeightModifierMix class

Inheritance
Mixed-in types

Properties

hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Type
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant IntrinsicHeightModifierMix? other) IntrinsicHeightModifierMix
Merges this instance with other, with other taking precedence.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) IntrinsicHeightModifier
Resolves this to a concrete value using the provided context.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited