KeyframeTrack<T> class

Constructors

KeyframeTrack(String id, List<Keyframe<T>> segments, {required T initial, TweenBuilder<T?>? tweenBuilder})

Properties

hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
id String
final
initial → T
final
props List<Object?>
The properties based on which equality and hash code are computed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<Keyframe<T>>
final
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited
totalDuration Duration
no setter
tweenBuilder TweenBuilder<T?>
final

Methods

createAnimatable(Duration timelineDuration) Animatable<T?>
Creates a tween for interpolating between two values. Uses the custom tweenBuilder if provided, otherwise falls back to default behavior.
createSequenceItems() List<TweenSequenceItem<T?>>
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Overrides string representation for debugging and logging.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited