LinearBorderMix class final

Mix-compatible representation of Flutter's LinearBorder with configurable edge styling.

Inheritance

Constructors

LinearBorderMix({BorderSideMix? side, LinearBorderEdgeMix? start, LinearBorderEdgeMix? end, LinearBorderEdgeMix? top, LinearBorderEdgeMix? bottom})
LinearBorderMix.bottom(LinearBorderEdgeMix value)
Creates a linear border with the specified bottom edge.
factory
LinearBorderMix.create({Prop<BorderSide>? side, Prop<LinearBorderEdge>? start, Prop<LinearBorderEdge>? end, Prop<LinearBorderEdge>? top, Prop<LinearBorderEdge>? bottom})
const
LinearBorderMix.end(LinearBorderEdgeMix value)
Creates a linear border with the specified end edge.
factory
LinearBorderMix.side(BorderSideMix value)
Creates a linear border with the specified border side.
factory
LinearBorderMix.start(LinearBorderEdgeMix value)
Creates a linear border with the specified start edge.
factory
LinearBorderMix.top(LinearBorderEdgeMix value)
Creates a linear border with the specified top edge.
factory
LinearBorderMix.value(LinearBorder border)

Properties

$bottom Prop<LinearBorderEdge>?
final
$end Prop<LinearBorderEdge>?
final
$side Prop<BorderSide>?
finalinherited
$start Prop<LinearBorderEdge>?
final
$top Prop<LinearBorderEdge>?
final
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

bottom(LinearBorderEdgeMix value) LinearBorderMix
Returns a copy with the specified bottom edge.
end(LinearBorderEdgeMix value) LinearBorderMix
Returns a copy with the specified end edge.
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant LinearBorderMix? other) LinearBorderMix
Merges instances of the same type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) LinearBorder
Resolves this to a concrete value using the provided context.
override
side(BorderSideMix value) LinearBorderMix
Copy with border side.
start(LinearBorderEdgeMix value) LinearBorderMix
Returns a copy with the specified start edge.
top(LinearBorderEdgeMix value) LinearBorderMix
Returns a copy with the specified top edge.
toString() String
Overrides string representation for debugging and logging.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited

Static Methods

maybeValue(LinearBorder? border) LinearBorderMix?
Creates from nullable ShapeBorder.
override