LowercaseStringDirective class final

Directive that converts a string to lowercase.

Inheritance

Constructors

LowercaseStringDirective()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
The unique identifier for this directive type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(String value) String
Applies the transformation to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override