MixColors class

A class that defines a comprehensive set of colors and color swatches for the Mix framework.

Similar to Flutter's Colors class, MixColors provides a wide range of Material Design color swatches along with basic colors like transparent, black, and white with opacity variants.

Example usage:

final boxStyle = BoxStyler().color(MixColors.blue);
final textStyle = TextStyler().color(MixColors.red);

For accessing specific shades:

MixColors.blueSwatch[300]  // Light blue
MixColors.redSwatch[700]   // Dark red

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber → const ColorSwatch<int>
amberAccent → const ColorSwatch<int>
amberAccentSwatch → const ColorSwatch<int>
amberSwatch → const ColorSwatch<int>
black → const Color
black12 → const Color
black26 → const Color
black38 → const Color
black45 → const Color
black54 → const Color
black87 → const Color
blue → const ColorSwatch<int>
blueAccent → const ColorSwatch<int>
blueAccentSwatch → const ColorSwatch<int>
blueGrey → const ColorSwatch<int>
blueGreySwatch → const ColorSwatch<int>
blueSwatch → const ColorSwatch<int>
brown → const ColorSwatch<int>
brownSwatch → const ColorSwatch<int>
cyan → const ColorSwatch<int>
cyanAccent → const ColorSwatch<int>
cyanAccentSwatch → const ColorSwatch<int>
cyanSwatch → const ColorSwatch<int>
deepOrange → const ColorSwatch<int>
deepOrangeAccent → const ColorSwatch<int>
deepOrangeAccentSwatch → const ColorSwatch<int>
deepOrangeSwatch → const ColorSwatch<int>
deepPurple → const ColorSwatch<int>
deepPurpleAccent → const ColorSwatch<int>
deepPurpleAccentSwatch → const ColorSwatch<int>
deepPurpleSwatch → const ColorSwatch<int>
green → const ColorSwatch<int>
greenAccent → const ColorSwatch<int>
greenAccentSwatch → const ColorSwatch<int>
greenSwatch → const ColorSwatch<int>
grey → const ColorSwatch<int>
greySwatch → const ColorSwatch<int>
indigo → const ColorSwatch<int>
indigoAccent → const ColorSwatch<int>
indigoAccentSwatch → const ColorSwatch<int>
indigoSwatch → const ColorSwatch<int>
lightBlue → const ColorSwatch<int>
lightBlueAccent → const ColorSwatch<int>
lightBlueAccentSwatch → const ColorSwatch<int>
lightBlueSwatch → const ColorSwatch<int>
lightGreen → const ColorSwatch<int>
lightGreenAccent → const ColorSwatch<int>
lightGreenAccentSwatch → const ColorSwatch<int>
lightGreenSwatch → const ColorSwatch<int>
lime → const ColorSwatch<int>
limeAccent → const ColorSwatch<int>
limeAccentSwatch → const ColorSwatch<int>
limeSwatch → const ColorSwatch<int>
orange → const ColorSwatch<int>
orangeAccent → const ColorSwatch<int>
orangeAccentSwatch → const ColorSwatch<int>
orangeSwatch → const ColorSwatch<int>
pink → const ColorSwatch<int>
pinkAccent → const ColorSwatch<int>
pinkAccentSwatch → const ColorSwatch<int>
pinkSwatch → const ColorSwatch<int>
purple → const ColorSwatch<int>
purpleAccent → const ColorSwatch<int>
purpleAccentSwatch → const ColorSwatch<int>
purpleSwatch → const ColorSwatch<int>
red → const ColorSwatch<int>
redAccent → const ColorSwatch<int>
redAccentSwatch → const ColorSwatch<int>
redSwatch → const ColorSwatch<int>
teal → const ColorSwatch<int>
tealAccent → const ColorSwatch<int>
tealAccentSwatch → const ColorSwatch<int>
tealSwatch → const ColorSwatch<int>
transparent → const Color
white → const Color
white10 → const Color
white12 → const Color
white24 → const Color
white30 → const Color
white38 → const Color
white54 → const Color
white60 → const Color
white70 → const Color
yellow → const ColorSwatch<int>
yellowAccent → const ColorSwatch<int>
yellowAccentSwatch → const ColorSwatch<int>
yellowSwatch → const ColorSwatch<int>