MixConverter<T> class abstract interface

Defines how to convert values to their Mix representations.

Implement this interface to create custom converters for your types. Converters receive a ConversionContext to enable nested conversions.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMix(T value, ConversionContext context) Mix<T>
Converts a value to its Mix representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited