MixStyler<ST extends Style<SP>, SP extends Spec<SP>> class abstract

Inheritance
Mixed-in types
Implementers

Constructors

MixStyler({required List<VariantStyle<SP>>? variants, required WidgetModifierConfig? modifier, required AnimationConfig? animation})
const

Properties

$animation AnimationConfig?
finalinherited
$modifier WidgetModifierConfig?
finalinherited
$variants List<VariantStyle<SP>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

animate(AnimationConfig config) → ST
inherited
applyVariants(Iterable<NamedVariant> variantsToApply) → ST
Applies the specified named variants by merging their styles into this style.
inherited
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<SP>
Builds the style into a fully resolved spec with metadata.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<SP, ST> styleBuilder}) → ST
Creates a keyframe animation. It will animate through the given timeline.
inherited
merge(covariant Style<SP>? other) Style<SP>
Merges this attribute with another attribute of the same type.
inherited
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<SP>
Merges all active variants with their nested variants recursively.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(ST style) → ST
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, ST style) → ST
Creates a variant based on the specified breakpoint.
inherited
onBuilder(ST fn(BuildContext context)) → ST
Creates a variant using a builder function that receives the build context.
inherited
onDark(ST style) → ST
Creates a variant for dark mode.
inherited
onDesktop(ST style) → ST
Creates a variant for desktop breakpoint.
inherited
onDisabled(ST style) → ST
Creates a variant for disabled state
inherited
onEnabled(ST style) → ST
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(ST style) → ST
Creates a variant for focused state.
inherited
onFuchsia(ST style) → ST
Creates a variant for Fuchsia platform.
inherited
onHovered(ST style) → ST
Creates a variant for hover state
inherited
onIos(ST style) → ST
Creates a variant for iOS platform.
inherited
onLandscape(ST style) → ST
Creates a variant for landscape device orientation.
inherited
onLight(ST style) → ST
Creates a variant for light mode.
inherited
onLinux(ST style) → ST
Creates a variant for Linux platform.
inherited
onLtr(ST style) → ST
Creates a variant for left-to-right text direction.
inherited
onMacos(ST style) → ST
Creates a variant for macOS platform.
inherited
onMobile(ST style) → ST
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, ST style) → ST
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(ST style) → ST
Creates a variant for portrait device orientation.
inherited
onPressed(ST style) → ST
Creates a variant for pressed state
inherited
onRtl(ST style) → ST
Creates a variant for right-to-left text direction.
inherited
onTablet(ST style) → ST
Creates a variant for tablet breakpoint.
inherited
onWeb(ST style) → ST
Creates a variant for web platform.
inherited
onWindows(ST style) → ST
Creates a variant for Windows platform.
inherited
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required ST styleBuilder(P phase, ST style), required CurveAnimationConfig configBuilder(P phase)}) → ST
Creates a phase animation. It will animate through the given phases.
inherited
resolve(BuildContext context) StyleSpec<SP>
Resolves this attribute to its concrete value using the provided BuildContext.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
variant(Variant variant, ST style) → ST
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<SP>> value) → ST
Sets the list of variant styles. Must be implemented by the class using this mixin.
inherited
wrap(WidgetModifierConfig value) → ST
Applies the given value widget modifier configuration.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited