Mixable<T> class
abstract
Base class for types that can be merged together.
Provides the ability to combine two instances of the same type, typically used for combining style properties.
- Implementers
Constructors
- Mixable()
-
const
Properties
Methods
-
merge(
covariant Mixable< T> ? other) → Mixable<T> -
Merges this instance with
other, withothertaking precedence. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited