ModifierMix<S extends WidgetModifier<S>> class abstract

Inheritance
Implementers

Constructors

ModifierMix()
const

Properties

hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Type
The key used to identify compatible types for merging.
no setteroverride
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant ModifierMix<S>? other) ModifierMix<S>
Merges this instance with other, with other taking precedence.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) → S
Resolves this to a concrete value using the provided context.
override
toString() String
Overrides string representation for debugging and logging.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited