OpacityColorDirective class

Directive that applies opacity to a color.

Inheritance

Constructors

OpacityColorDirective(double opacity)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
The unique identifier for this directive type.
no setteroverride
opacity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Color color) Color
Applies the transformation to the given value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override