PaddingModifier class final

Modifier that adds padding around its child.

Wraps the child in a Padding widget with the specified padding.

Implemented types
Annotations
  • @MixableModifier.new()

Constructors

PaddingModifier([EdgeInsetsGeometry? padding])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry
final
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited
type Type
no setterinherited

Methods

build(Widget child) Widget
Builds the modified widget by wrapping or transforming child.
copyWith({EdgeInsetsGeometry? padding}) PaddingModifier
Creates a copy of this spec with the given fields replaced by the non-null parameter values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
lerp(covariant PaddingModifier? other, double t) PaddingModifier
Linearly interpolates with another Spec object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited