sources property
The list of sources that provide values for this property.
Sources can be ValueSource, TokenSource, or MixSource.
Implementation
final List<PropSource<V>> sources;
The list of sources that provide values for this property.
Sources can be ValueSource, TokenSource, or MixSource.
final List<PropSource<V>> sources;