RadiusRef class final

Token reference for Radius values

Inheritance
Implemented types
Mixed-in types

Constructors

RadiusRef(Prop<Radius> prop)

Properties

$directives List<Directive<Radius>>?
Optional directives to transform the resolved value.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
Whether this property contains at least one token source.
no setterinherited
hasValue bool
Whether this property contains at least one value source.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<PropSource<Radius>>
The list of sources that provide values for this property.
finalinherited
type Type
The runtime type of the property's value.
no setterinherited
x double
The radius value on the horizontal axis.
finalinherited
y double
The radius value on the vertical axis.
finalinherited

Methods

clamp({Radius? minimum, Radius? maximum}) Radius
Returns this Radius, with values clamped to the given min and max Radius values.
inherited
clampValues({double? minimumX, double? minimumY, double? maximumX, double? maximumY}) Radius
Returns this Radius, with values clamped to the given min and max values in each dimension
inherited
directives(List<Directive<Radius>> directives) Prop<Radius>
Returns a new property with the given directives merged with existing ones.
inherited
mergeProp(covariant Prop<Radius>? other) Prop<Radius>
Merges this property with another property.
inherited
noSuchMethod(Invocation invocation) → Never
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator %(double operand) Radius
Modulo (remainder) operator.
inherited
operator *(double operand) Radius
Multiplication operator.
inherited
operator +(Radius other) Radius
Binary addition operator.
inherited
operator -(Radius other) Radius
Binary subtraction operator.
inherited
operator /(double operand) Radius
Division operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator unary-() Radius
Unary negation operator.
inherited
operator ~/(double operand) Radius
Integer (truncating) division operator.
inherited