Resolvable<V> mixin

Mixin for types that can be resolved to a value using a BuildContext.

Provides the ability to resolve context-dependent values like tokens, responsive properties, or theme-dependent values.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) → V
Resolves this to a concrete value using the provided context.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited