RoundedSuperellipseBorderMix class final

Mix-compatible representation of Flutter's RoundedSuperellipseBorder with smoother corners.

Inheritance

Constructors

RoundedSuperellipseBorderMix({BorderRadiusGeometryMix<BorderRadiusGeometry>? borderRadius, BorderSideMix? side})
RoundedSuperellipseBorderMix.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
Creates a rounded superellipse border with the specified border radius.
factory
RoundedSuperellipseBorderMix.create({Prop<BorderRadiusGeometry>? borderRadius, Prop<BorderSide>? side})
const
RoundedSuperellipseBorderMix.side(BorderSideMix value)
Creates a rounded superellipse border with the specified border side.
factory
RoundedSuperellipseBorderMix.value(RoundedSuperellipseBorder border)

Properties

$borderRadius Prop<BorderRadiusGeometry>?
final
$side Prop<BorderSide>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) RoundedSuperellipseBorderMix
Copy with border radius.
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant RoundedSuperellipseBorderMix? other) RoundedSuperellipseBorderMix
Merges instances of the same type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) RoundedSuperellipseBorder
Resolves this to a concrete value using the provided context.
override
side(BorderSideMix value) RoundedSuperellipseBorderMix
Copy with border side.
toString() String
Overrides string representation for debugging and logging.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited

Static Methods

maybeValue(RoundedSuperellipseBorder? border) RoundedSuperellipseBorderMix?
Creates from nullable ShapeBorder.
override