ShadowListRef class final

Token reference for List<Shadow> values

Inheritance
Implemented types
Mixed-in types

Constructors

ShadowListRef(Prop<List<Shadow>> prop)

Properties

$directives List<Directive<List<Shadow>>>?
Optional directives to transform the resolved value.
finalinherited
first Shadow
The first element.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
Whether this property contains at least one token source.
no setterinherited
hasValue bool
Whether this property contains at least one value source.
no setterinherited
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<Shadow>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last Shadow
The last element.
getter/setter pairinherited
length int
The number of objects in this list.
getter/setter pairinherited
reversed Iterable<Shadow>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single Shadow
Checks that this iterable has only one element, and returns that element.
no setterinherited
sources List<PropSource<List<Shadow>>>
The list of sources that provide values for this property.
finalinherited
type Type
The runtime type of the property's value.
no setterinherited

Methods

add(Shadow value) → void
Adds value to the end of this list, extending the length by one.
inherited
addAll(Iterable<Shadow> iterable) → void
Appends all objects of iterable to the end of this list.
inherited
any(bool test(Shadow element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, Shadow>
An unmodifiable Map view of this list.
inherited
cast<R>() List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
directives(List<Directive<List<Shadow>>> directives) Prop<List<Shadow>>
Returns a new property with the given directives merged with existing ones.
inherited
elementAt(int index) Shadow
Returns the indexth element.
inherited
every(bool test(Shadow element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Shadow element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [Shadow? fillValue]) → void
Overwrites a range of elements with fillValue.
inherited
firstWhere(bool test(Shadow element), {Shadow orElse()?}) Shadow
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Shadow element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Shadow> other) Iterable<Shadow>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Shadow element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end) Iterable<Shadow>
Creates an Iterable that iterates over a range of elements.
inherited
indexOf(Shadow element, [int start = 0]) int
The first index of element in this list.
inherited
indexWhere(bool test(Shadow element), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
insert(int index, Shadow element) → void
Inserts element at position index in this list.
inherited
insertAll(int index, Iterable<Shadow> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Shadow element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(Shadow element), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(Shadow element), {Shadow orElse()?}) Shadow
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Shadow e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mergeProp(covariant Prop<List<Shadow>>? other) Prop<List<Shadow>>
Merges this property with another property.
inherited
noSuchMethod(Invocation invocation) → Never
Invoked when a nonexistent method or property is accessed.
inherited
reduce(Shadow combine(Shadow value, Shadow element)) Shadow
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) Shadow
Removes the object at position index from this list.
inherited
removeLast() Shadow
Removes and returns the last object in this list.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
inherited
removeWhere(bool test(Shadow element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<Shadow> replacements) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(Shadow element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
setAll(int index, Iterable<Shadow> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<Shadow> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(Shadow element), {Shadow orElse()?}) Shadow
The single element that satisfies test.
inherited
skip(int count) Iterable<Shadow>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Shadow value)) Iterable<Shadow>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
sort([int compare(Shadow a, Shadow b)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sublist(int start, [int? end]) List<Shadow>
Returns a new list containing the elements between start and end.
inherited
take(int count) Iterable<Shadow>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Shadow value)) Iterable<Shadow>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<Shadow>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<Shadow>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
inherited
where(bool test(Shadow element)) Iterable<Shadow>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<Shadow> other) List<Shadow>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) Shadow
The object at the given index in the list.
inherited
operator []=(int index, Shadow value) → void
Sets the value at the given index in the list to value.
inherited