ShadowToken class
Design token for shadow lists.
Constructors
- ShadowToken(String name)
-
const
Properties
Methods
-
call(
) → ShadowListRef -
Returns a reference value for Mix utilities.
override
-
mix(
) → ShadowListMixRef - Returns a Mix framework compatible reference for use with Mix styling utilities.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → List< Shadow> -
Resolves this token to a concrete value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited