ShapeBorderRef class final

Token reference for ShapeBorder values

Inheritance
Implemented types
Mixed-in types

Constructors

ShapeBorderRef(Prop<ShapeBorder> prop)

Properties

$directives List<Directive<ShapeBorder>>?
Optional directives to transform the resolved value.
finalinherited
dimensions EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasToken bool
Whether this property contains at least one token source.
no setterinherited
hasValue bool
Whether this property contains at least one value source.
no setterinherited
preferPaintInterior bool
Reports whether paintInterior is implemented.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<PropSource<ShapeBorder>>
The list of sources that provide values for this property.
finalinherited
type Type
The runtime type of the property's value.
no setterinherited

Methods

add(ShapeBorder other, {bool reversed = false}) ShapeBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
directives(List<Directive<ShapeBorder>> directives) Prop<ShapeBorder>
Returns a new property with the given directives merged with existing ones.
inherited
getInnerPath(Rect rect, {TextDirection? textDirection}) Path
Create a Path that describes the inner edge of the border.
inherited
getOuterPath(Rect rect, {TextDirection? textDirection}) Path
Create a Path that describes the outer edge of the border.
inherited
lerpFrom(ShapeBorder? a, double t) ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
mergeProp(covariant Prop<ShapeBorder>? other) Prop<ShapeBorder>
Merges this property with another property.
inherited
noSuchMethod(Invocation invocation) → Never
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) → void
Paints the border within the given Rect on the given Canvas.
inherited
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) ShapeBorder
Creates a copy of this border, scaled by the factor t.
inherited
toString({DiagnosticLevel minLevel = .info}) String
A string representation of this object.
override

Operators

operator +(ShapeBorder other) ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited