VariantAttribute<V extends IVariant> class

Inheritance
Mixed-in types
Implementers
Annotations

Constructors

VariantAttribute(V variant, Style style)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mergeKey Object
no setteroverride
priority VariantPriority
no setter
props List<Object?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
no setterinherited
value Style
no setter
variant → V
final

Methods

getDiff(Comparable other) Map<String, String>
inherited
matches(Iterable<IVariant> otherVariants) bool
merge(covariant VariantAttribute<V>? other) VariantAttribute<V>
Merges this object with other, returning a new object of type T.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeVariants(Iterable<IVariant> variantsToRemove) VariantAttribute<IVariant>?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited