WebVariant class final

Context variant that applies when running on the web.

Inheritance

Constructors

WebVariant()

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
Human-readable label used for diagnostics.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldApply bool Function(BuildContext)
finalinherited
widgetStateDependencies Set<WidgetState>
Widget states that must be tracked for this variant to be evaluated.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when(BuildContext context) bool
Check if this variant should be active for the given context
inherited

Operators

operator ==(Object other) bool
The equality operator.
override