AlignmentDirectionalRef class final
Token reference for AlignmentDirectional values
- Inheritance
-
- Object
- Prop<
AlignmentDirectional> - AlignmentDirectionalRef
- Implemented types
- Mixed-in types
Constructors
Properties
-
$directives
→ List<
Directive< ?AlignmentDirectional> > -
Optional directives to transform the resolved value.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasToken → bool
-
Whether this property contains at least one token source.
no setterinherited
- hasValue → bool
-
Whether this property contains at least one value source.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
→ List<
PropSource< AlignmentDirectional> > -
The list of sources that provide values for this property.
finalinherited
- start → double
-
The distance fraction in the horizontal direction.
finalinherited
- type → Type
-
The runtime type of the property's value.
no setterinherited
- y → double
-
The distance fraction in the vertical direction.
finalinherited
Methods
-
add(
AlignmentGeometry other) → AlignmentGeometry -
Returns the sum of two AlignmentGeometry objects.
inherited
-
directives(
List< Directive< directives) → Prop<AlignmentDirectional> >AlignmentDirectional> -
Returns a new property with the given directives merged with existing ones.
inherited
-
mergeProp(
covariant Prop< AlignmentDirectional> ? other) → Prop<AlignmentDirectional> -
Merges this property with another property.
inherited
-
noSuchMethod(
Invocation invocation) → Never -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection? direction) → Alignment -
Convert this instance into an Alignment, which uses literal
coordinates (the
xcoordinate being explicitly a distance from the left).inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator %(
double other) → AlignmentDirectional -
Computes the remainder in each dimension by the given factor.
inherited
-
operator *(
double other) → AlignmentDirectional -
Scales the AlignmentDirectional in each dimension by the given factor.
inherited
-
operator +(
AlignmentDirectional other) → AlignmentDirectional -
Returns the sum of two AlignmentDirectionals.
inherited
-
operator -(
AlignmentDirectional other) → AlignmentDirectional -
Returns the difference between two AlignmentDirectionals.
inherited
-
operator /(
double other) → AlignmentDirectional -
Divides the AlignmentDirectional in each dimension by the given factor.
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → AlignmentDirectional -
Returns the negation of the given AlignmentDirectional.
inherited
-
operator ~/(
double other) → AlignmentDirectional -
Integer divides the AlignmentDirectional in each dimension by the given factor.
inherited