BorderRadiusGeometryMix<T extends BorderRadiusGeometry> class
sealed
Base class for Mix border radius types.
Supports automatic type conversion and merging.
- Inheritance
- Implementers
- Annotations
Constructors
- BorderRadiusGeometryMix.value(BorderRadiusGeometry value)
-
factory
Properties
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
The key used to identify compatible types for merging.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
merge(
covariant BorderRadiusGeometryMix< T> ? other) → BorderRadiusGeometryMix<T> -
Merges with another instance.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → T -
Resolves this to a concrete value using the provided
context.inherited -
toString(
) → String -
Overrides string representation for debugging and logging.
inherited
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited
Static Methods
-
all(
Radius radius) → BorderRadiusMix -
bottom(
Radius radius) → BorderRadiusMix -
bottomEnd(
Radius radius) → BorderRadiusDirectionalMix - Creates with bottom-end corner only.
-
bottomLeft(
Radius radius) → BorderRadiusMix - Creates with bottom-left corner only.
-
bottomRight(
Radius radius) → BorderRadiusMix - Creates with bottom-right corner only.
-
bottomStart(
Radius radius) → BorderRadiusDirectionalMix - Creates with bottom-start corner only.
-
circular(
double radius) → BorderRadiusMix - Creates circular radius for all corners.
-
elliptical(
double xRadius, double yRadius) → BorderRadiusMix - Creates elliptical radius for all corners.
-
left(
Radius radius) → BorderRadiusMix -
maybeValue<
T extends BorderRadiusGeometry> (T? value) → BorderRadiusGeometryMix< T> ? -
only(
{Radius? topLeft, Radius? topRight, Radius? bottomLeft, Radius? bottomRight, Radius? topStart, Radius? topEnd, Radius? bottomStart, Radius? bottomEnd}) → BorderRadiusGeometryMix< BorderRadiusGeometry> -
right(
Radius radius) → BorderRadiusMix -
top(
Radius radius) → BorderRadiusMix -
topEnd(
Radius radius) → BorderRadiusDirectionalMix - Creates with top-end corner only.
-
topLeft(
Radius radius) → BorderRadiusMix - Creates with top-left corner only.
-
topRight(
Radius radius) → BorderRadiusMix - Creates with top-right corner only.
-
topStart(
Radius radius) → BorderRadiusDirectionalMix - Creates with top-start corner only.
-
tryToMerge(
BorderRadiusGeometryMix< BorderRadiusGeometry> ? a, BorderRadiusGeometryMix<BorderRadiusGeometry> ? b) → BorderRadiusGeometryMix<BorderRadiusGeometry> ? - Merges with automatic type conversion.