BorderRadiusGeometryRef class final
Token reference for BorderRadiusGeometry values
- Inheritance
-
- Object
- Prop<
BorderRadiusGeometry> - BorderRadiusGeometryRef
- Implemented types
- Mixed-in types
Constructors
Properties
-
$directives
→ List<
Directive< ?BorderRadiusGeometry> > -
Optional directives to transform the resolved value.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasToken → bool
-
Whether this property contains at least one token source.
no setterinherited
- hasValue → bool
-
Whether this property contains at least one value source.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
→ List<
PropSource< BorderRadiusGeometry> > -
The list of sources that provide values for this property.
finalinherited
- type → Type
-
The runtime type of the property's value.
no setterinherited
Methods
-
add(
BorderRadiusGeometry other) → BorderRadiusGeometry -
Returns the sum of two BorderRadiusGeometry objects.
inherited
-
directives(
List< Directive< directives) → Prop<BorderRadiusGeometry> >BorderRadiusGeometry> -
Returns a new property with the given directives merged with existing ones.
inherited
-
mergeProp(
covariant Prop< BorderRadiusGeometry> ? other) → Prop<BorderRadiusGeometry> -
Merges this property with another property.
inherited
-
noSuchMethod(
Invocation invocation) → Never -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection? direction) → BorderRadius -
Convert this instance into a BorderRadius, so that the radii are
expressed for specific physical corners (top-left, top-right, etc) rather
than in a direction-dependent manner.
inherited
-
subtract(
BorderRadiusGeometry other) → BorderRadiusGeometry -
Returns the difference between two BorderRadiusGeometry objects.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator %(
double other) → BorderRadiusGeometry -
Computes the remainder of each corner by the given factor.
inherited
-
operator *(
double other) → BorderRadiusGeometry -
Scales the BorderRadiusGeometry object's corners by the given factor.
inherited
-
operator /(
double other) → BorderRadiusGeometry -
Divides the BorderRadiusGeometry object's corners by the given factor.
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → BorderRadiusGeometry -
Returns the BorderRadiusGeometry object with each corner radius negated.
inherited
-
operator ~/(
double other) → BorderRadiusGeometry -
Integer divides the BorderRadiusGeometry object's corners by the given factor.
inherited