CurveAnimationDriver<S extends Spec<S> > class
A driver for curve-based animations with fixed duration.
- Inheritance
-
- Object
- StyleAnimationDriver<
S> - ImplicitAnimationDriver<
S, CurveAnimationConfig> - CurveAnimationDriver
Constructors
-
CurveAnimationDriver({required TickerProvider vsync, required CurveAnimationConfig config, required StyleSpec<
S> initialSpec})
Properties
-
animation
→ Animation<
StyleSpec< S> ?> -
Gets the animation that drives spec changes.
no setterinherited
- config ↔ CurveAnimationConfig
-
getter/setter pairinherited
- controller → AnimationController
-
Gets the current animation controller.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
The ticker provider for animations.
finalinherited
Methods
-
didUpdateSpec(
StyleSpec< S> oldSpec, StyleSpec<S> newSpec) → void -
inherited
-
dispose(
) → void -
inherited
-
executeAnimation(
) → Future< void> -
Execute the animation (curve vs spring).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCompleteAnimation(
) → void -
override
-
reset(
) → void -
Resets the animation to the beginning.
inherited
-
stop(
) → void -
Stops the current animation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDriver(
covariant CurveAnimationConfig config) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited