Directive<T> class
abstract
Base class for directives that apply transformations to values.
Directives provide a way to transform values like colors or strings in a consistent, composable manner throughout the Mix framework.
- Implementers
- AlphaColorDirective
- BrightenColorDirective
- CapitalizeStringDirective
- DarkenColorDirective
- DesaturateColorDirective
- LightenColorDirective
- LowercaseStringDirective
- NumberDirective
- OpacityColorDirective
- SaturateColorDirective
- SentenceCaseStringDirective
- ShadeColorDirective
- TintColorDirective
- TitleCaseStringDirective
- UppercaseStringDirective
- WithBlueColorDirective
- WithGreenColorDirective
- WithRedColorDirective
- WithValuesColorDirective
- Annotations
Constructors
- Directive()
-
const
Properties
Methods
-
apply(
T value) → T - Applies the transformation to the given value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited