EdgeInsetsDirectionalMix class final
Mix representation of EdgeInsetsDirectional.
Uses directional positioning (start, end) with token support.
- Inheritance
-
- Object
- Mixable<
EdgeInsetsDirectional> - Mix<
EdgeInsetsDirectional> - EdgeInsetsGeometryMix<
EdgeInsetsDirectional> - EdgeInsetsDirectionalMix
- Mixed-in types
- Annotations
-
- @Mixable.new(methods: GeneratedMixMethods.skipResolve)
Constructors
- EdgeInsetsDirectionalMix({double? top, double? bottom, double? start, double? end})
- EdgeInsetsDirectionalMix.all(double value)
-
EdgeInsetsDirectionalMix.create({Prop<
double> ? top, Prop<double> ? bottom, Prop<double> ? start, Prop<double> ? end}) -
const
- EdgeInsetsDirectionalMix.fromSTEB(double start, double top, double end, double bottom)
- EdgeInsetsDirectionalMix.horizontal(double value)
- EdgeInsetsDirectionalMix.none()
- EdgeInsetsDirectionalMix.symmetric({double? vertical, double? horizontal})
- EdgeInsetsDirectionalMix.value(EdgeInsetsDirectional edgeInsets)
-
Creates from existing EdgeInsetsDirectional.
factory
- EdgeInsetsDirectionalMix.vertical(double value)
Properties
-
$bottom
→ Prop<
double> ? -
no setterinherited
-
$end
→ Prop<
double> ? -
final
-
$start
→ Prop<
double> ? -
final
-
$top
→ Prop<
double> ? -
no setterinherited
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
The key used to identify compatible types for merging.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
bottom(
double value) → EdgeInsetsDirectionalMix -
Copy with bottom inset.
override
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
directional(
{double? start, double? end, double? top, double? bottom}) → EdgeInsetsDirectionalMix -
Copy with directional insets.
override
-
end(
double value) → EdgeInsetsDirectionalMix -
Copy with end inset.
override
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
merge(
covariant EdgeInsetsDirectionalMix? other) → EdgeInsetsDirectionalMix -
Merges with another EdgeInsetsDirectionalMix.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → EdgeInsetsDirectional -
Resolves this to a concrete value using the provided
context.override -
start(
double value) → EdgeInsetsDirectionalMix -
Copy with start inset.
override
-
symmetric(
{double? vertical, double? horizontal}) → EdgeInsetsDirectionalMix -
Copy with symmetric insets.
override
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
top(
double value) → EdgeInsetsDirectionalMix -
Copy with top inset.
override
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited
Static Properties
- zero ↔ EdgeInsetsDirectionalMix
-
getter/setter pair
Static Methods
-
maybeValue(
EdgeInsetsDirectional? edgeInsets) → EdgeInsetsDirectionalMix? -
Creates from nullable EdgeInsetsDirectional.
override