EdgeInsetsMix class final
Mix representation of EdgeInsets.
Uses absolute positioning (left, right) with token support.
- Inheritance
-
- Object
- Mixable<
EdgeInsets> - Mix<
EdgeInsets> - EdgeInsetsGeometryMix<
EdgeInsets> - EdgeInsetsMix
- Mixed-in types
- Annotations
-
- @Mixable.new(methods: GeneratedMixMethods.skipResolve)
Constructors
- EdgeInsetsMix({double? top, double? bottom, double? left, double? right})
- EdgeInsetsMix.all(double value)
-
EdgeInsetsMix.create({Prop<
double> ? top, Prop<double> ? bottom, Prop<double> ? left, Prop<double> ? right}) -
const
- EdgeInsetsMix.fromLTRB(double left, double top, double right, double bottom)
- EdgeInsetsMix.horizontal(double value)
- EdgeInsetsMix.none()
- EdgeInsetsMix.symmetric({double? vertical, double? horizontal})
- EdgeInsetsMix.value(EdgeInsets edgeInsets)
- Creates from existing EdgeInsets.
- EdgeInsetsMix.vertical(double value)
Properties
-
$bottom
→ Prop<
double> ? -
no setterinherited
-
$left
→ Prop<
double> ? -
final
-
$right
→ Prop<
double> ? -
final
-
$top
→ Prop<
double> ? -
no setterinherited
- defaultValue → EdgeInsets
-
The default value to use when no explicit value is available.
no setteroverride
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
The key used to identify compatible types for merging.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
bottom(
double value) → EdgeInsetsMix -
Copy with bottom inset.
override
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
horizontal(
double value) → EdgeInsetsMix -
Copy with horizontal insets.
override
-
left(
double value) → EdgeInsetsMix -
Copy with left inset.
override
-
merge(
covariant EdgeInsetsMix? other) → EdgeInsetsMix -
Merges with another EdgeInsetsMix.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
only(
{double? left, double? right, double? top, double? bottom}) → EdgeInsetsMix -
Copy with only specified insets.
override
-
resolve(
BuildContext context) → EdgeInsets -
Resolves this to a concrete value using the provided
context.override -
right(
double value) → EdgeInsetsMix -
Copy with right inset.
override
-
symmetric(
{double? vertical, double? horizontal}) → EdgeInsetsMix -
Copy with symmetric insets.
override
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
top(
double value) → EdgeInsetsMix -
Copy with top inset.
override
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
vertical(
double value) → EdgeInsetsMix -
Copy with vertical insets.
override
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited
Static Properties
- zero ↔ EdgeInsetsMix
-
Zero padding.
getter/setter pair
Static Methods
-
maybeValue(
EdgeInsets? edgeInsets) → EdgeInsetsMix? -
Creates from nullable EdgeInsets.
override