NoAnimationDriver<S extends Spec<S> > class
A driver that bypasses all animation and immediately applies spec changes.
This driver provides instant spec updates without any interpolation, timers, or animation lifecycle. Useful for testing or when animations should be disabled (e.g., for accessibility).
- Inheritance
-
- Object
- StyleAnimationDriver<
S> - NoAnimationDriver
Constructors
-
NoAnimationDriver({required TickerProvider vsync, required StyleSpec<
S> initialSpec})
Properties
-
animation
→ Animation<
StyleSpec< S> ?> -
Gets the animation that drives spec changes.
no setterinherited
- controller → AnimationController
-
Gets the current animation controller.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
The ticker provider for animations.
finalinherited
Methods
-
didUpdateSpec(
StyleSpec< S> oldSpec, StyleSpec<S> newSpec) → void -
override
-
dispose(
) → void -
inherited
-
executeAnimation(
) → Future< void> -
Execute the animation (curve vs spring).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
Resets the animation to the beginning.
inherited
-
stop(
) → void -
Stops the current animation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDriver(
AnimationConfig config) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited