ScaleModifier class
- Inheritance
-
- Object
- Spec<
ScaleModifier> - WidgetModifier<
ScaleModifier> - ScaleModifier
Constructors
- ScaleModifier({double x = 1.0, double y = 1.0, Alignment? alignment = Alignment.center})
Properties
- alignment → Alignment?
-
finalinherited
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
- transform → Matrix4
-
finalinherited
- type → Type
-
no setterinherited
Methods
-
build(
Widget child) → Widget -
Builds the modified widget by wrapping or transforming
child.inherited -
copyWith(
{double? x, double? y, Alignment? alignment}) → ScaleModifier -
Creates a copy of this spec with the given fields
replaced by the non-null parameter values.
override
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
lerp(
covariant ScaleModifier? other, double t) → ScaleModifier -
Linearly interpolates with another Spec object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited