StyleAnimationDriver<S extends Spec<S> > class
abstract
Base class for animation drivers that handle style interpolation.
Animation drivers define how styles should be animated between changes. This base class provides lifecycle management and common animation control methods.
Constructors
-
StyleAnimationDriver({required TickerProvider vsync, required StyleSpec<
S> initialSpec, bool unbounded = false})
Properties
-
animation
→ Animation<
StyleSpec< S> ?> -
Gets the animation that drives spec changes.
no setter
- controller → AnimationController
-
Gets the current animation controller.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
The ticker provider for animations.
final
Methods
-
didUpdateSpec(
StyleSpec< S> oldSpec, StyleSpec<S> newSpec) → void -
dispose(
) → void -
executeAnimation(
) → Future< void> - Execute the animation (curve vs spring).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Resets the animation to the beginning.
-
stop(
) → void - Stops the current animation.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDriver(
AnimationConfig config) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited