TableBorderRef class final
Token reference for TableBorder values
- Inheritance
-
- Object
- Prop<
TableBorder> - TableBorderRef
- Implemented types
- Mixed-in types
Constructors
-
TableBorderRef(Prop<
TableBorder> prop)
Properties
-
$directives
→ List<
Directive< ?TableBorder> > -
Optional directives to transform the resolved value.
finalinherited
- borderRadius → BorderRadius
-
The BorderRadius to use when painting the corners of this border.
finalinherited
- bottom → BorderSide
-
The bottom side of this border.
finalinherited
- dimensions → EdgeInsets
-
The widths of the sides of this border represented as an EdgeInsets.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasToken → bool
-
Whether this property contains at least one token source.
no setterinherited
- hasValue → bool
-
Whether this property contains at least one value source.
no setterinherited
- horizontalInside → BorderSide
-
The horizontal interior sides of this border.
finalinherited
- isUniform → bool
-
Whether all the sides of the border (outside and inside) are identical.
Uniform borders are typically more efficient to paint.
no setterinherited
- left → BorderSide
-
The left side of this border.
finalinherited
- right → BorderSide
-
The right side of this border.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
→ List<
PropSource< TableBorder> > -
The list of sources that provide values for this property.
finalinherited
- top → BorderSide
-
The top side of this border.
finalinherited
- type → Type
-
The runtime type of the property's value.
no setterinherited
- verticalInside → BorderSide
-
The vertical interior sides of this border.
finalinherited
Methods
-
directives(
List< Directive< directives) → Prop<TableBorder> >TableBorder> -
Returns a new property with the given directives merged with existing ones.
inherited
-
mergeProp(
covariant Prop< TableBorder> ? other) → Prop<TableBorder> -
Merges this property with another property.
inherited
-
noSuchMethod(
Invocation invocation) → Never -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Rect rect, {required Iterable< double> rows, required Iterable<double> columns}) → void -
Paints the border around the given Rect on the given Canvas, with the
given rows and columns.
inherited
-
scale(
double t) → TableBorder -
Creates a copy of this border but with the widths scaled by the factor
t.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited