ValueSource<V> class
A source that holds a direct value.
Created when a property is initialized with a concrete value that doesn't require context resolution or conversion.
- Inheritance
-
- Object
- PropSource<
V> - ValueSource
- Mixed-in types
- Annotations
Constructors
- ValueSource(V value)
-
const
Properties
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
- value → V
-
final
Methods
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited