WrapStyler class
- Inheritance
-
- Implemented types
-
- Mixed-in types
-
Constructors
-
WrapStyler({Axis? direction, WrapAlignment? alignment, double? spacing, WrapAlignment? runAlignment, double? runSpacing, WrapCrossAlignment? crossAxisAlignment, TextDirection? textDirection, VerticalDirection? verticalDirection, Clip? clipBehavior, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<WrapSpec>>? variants})
-
-
WrapStyler.alignment(WrapAlignment value)
-
factory
-
WrapStyler.clipBehavior(Clip value)
-
factory
-
WrapStyler.create({Prop<Axis>? direction, Prop<WrapAlignment>? alignment, Prop<double>? spacing, Prop<WrapAlignment>? runAlignment, Prop<double>? runSpacing, Prop<WrapCrossAlignment>? crossAxisAlignment, Prop<TextDirection>? textDirection, Prop<VerticalDirection>? verticalDirection, Prop<Clip>? clipBehavior, List<VariantStyle<WrapSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
-
const
-
WrapStyler.crossAxisAlignment(WrapCrossAlignment value)
-
factory
-
WrapStyler.direction(Axis value)
-
factory
-
WrapStyler.runAlignment(WrapAlignment value)
-
factory
-
WrapStyler.runSpacing(double value)
-
factory
-
WrapStyler.spacing(double value)
-
factory
-
WrapStyler.textDirection(TextDirection value)
-
factory
-
WrapStyler.verticalDirection(VerticalDirection value)
-
factory
-
WrapStyler.wrapAlignment(WrapAlignment value)
-
factory
-
WrapStyler.wrapClipBehavior(Clip value)
-
factory
Methods
-
alignment(WrapAlignment value)
→ WrapStyler
-
Sets the alignment.
-
animate(AnimationConfig value)
→ WrapStyler
-
Sets the animation configuration.
override
-
applyVariants(Iterable<NamedVariant> variantsToApply)
→ WrapStyler
-
Applies the specified named variants by merging their styles into this style.
inherited
-
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}})
→ StyleSpec<WrapSpec>
-
Builds the style into a fully resolved spec with metadata.
inherited
-
clipBehavior(Clip value)
→ WrapStyler
-
Sets the clipBehavior.
-
crossAxisAlignment(WrapCrossAlignment value)
→ WrapStyler
-
Sets the crossAxisAlignment.
override
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
override
-
direction(Axis value)
→ WrapStyler
-
Sets the direction.
override
-
flow(WrapStyler value)
→ WrapStyler
-
Merges a complete Wrap style into this styler.
override
-
getDiff(Equatable other)
→ Map<String, String>
-
Returns a map of properties that differ between this object and another.
inherited
-
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<WrapSpec, WrapStyler> styleBuilder})
→ WrapStyler
-
Creates a keyframe animation. It will animate through the given timeline.
inherited
-
merge(covariant WrapStyler? other)
→ WrapStyler
-
Merges with another WrapStyler.
override
-
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants})
→ Style<WrapSpec>
-
Merges all active variants with their nested variants recursively.
inherited
-
modifier(WidgetModifierConfig value)
→ WrapStyler
-
Sets the widget modifier.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onAndroid(WrapStyler style)
→ WrapStyler
-
Creates a variant for Android platform.
inherited
-
onBreakpoint(Breakpoint breakpoint, WrapStyler style)
→ WrapStyler
-
Creates a variant based on the specified breakpoint.
inherited
-
onBuilder(WrapStyler fn(BuildContext context))
→ WrapStyler
-
Creates a variant using a builder function that receives the build context.
inherited
-
onDark(WrapStyler style)
→ WrapStyler
-
Creates a variant for dark mode.
inherited
-
onDesktop(WrapStyler style)
→ WrapStyler
-
Creates a variant for desktop breakpoint.
inherited
-
onDisabled(WrapStyler style)
→ WrapStyler
-
Creates a variant for disabled state
inherited
-
onEnabled(WrapStyler style)
→ WrapStyler
-
Creates a variant for enabled state (opposite of disabled)
inherited
-
onFocused(WrapStyler style)
→ WrapStyler
-
Creates a variant for focused state.
inherited
-
onFocusVisible(WrapStyler style)
→ WrapStyler
-
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
-
onFuchsia(WrapStyler style)
→ WrapStyler
-
Creates a variant for Fuchsia platform.
inherited
-
onHovered(WrapStyler style)
→ WrapStyler
-
Creates a variant for hover state
inherited
-
onIos(WrapStyler style)
→ WrapStyler
-
Creates a variant for iOS platform.
inherited
-
onLandscape(WrapStyler style)
→ WrapStyler
-
Creates a variant for landscape device orientation.
inherited
-
onLight(WrapStyler style)
→ WrapStyler
-
Creates a variant for light mode.
inherited
-
onLinux(WrapStyler style)
→ WrapStyler
-
Creates a variant for Linux platform.
inherited
-
onLtr(WrapStyler style)
→ WrapStyler
-
Creates a variant for left-to-right text direction.
inherited
-
onMacos(WrapStyler style)
→ WrapStyler
-
Creates a variant for macOS platform.
inherited
-
onMobile(WrapStyler style)
→ WrapStyler
-
Creates a variant for mobile breakpoint.
inherited
-
onNot(ContextVariant contextVariant, WrapStyler style)
→ WrapStyler
-
Creates a variant for when the context does NOT match the provided variant.
inherited
-
onPortrait(WrapStyler style)
→ WrapStyler
-
Creates a variant for portrait device orientation.
inherited
-
onPressed(WrapStyler style)
→ WrapStyler
-
Creates a variant for pressed state
inherited
-
onRtl(WrapStyler style)
→ WrapStyler
-
Creates a variant for right-to-left text direction.
inherited
-
onTablet(WrapStyler style)
→ WrapStyler
-
Creates a variant for tablet breakpoint.
inherited
-
onWeb(WrapStyler style)
→ WrapStyler
-
Creates a variant for web platform.
inherited
-
onWindows(WrapStyler style)
→ WrapStyler
-
Creates a variant for Windows platform.
inherited
-
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required WrapStyler styleBuilder(P phase, WrapStyler style), required CurveAnimationConfig configBuilder(P phase)})
→ WrapStyler
-
Creates a phase animation. It will animate through the given phases.
inherited
-
resolve(BuildContext context)
→ StyleSpec<WrapSpec>
-
Resolves to StyleSpec<WrapSpec> using
context.
override
-
runAlignment(WrapAlignment value)
→ WrapStyler
-
Sets the runAlignment.
override
-
runSpacing(double value)
→ WrapStyler
-
Sets the runSpacing.
override
-
spacing(double value)
→ WrapStyler
-
Sets the spacing.
override
-
textDirection(TextDirection value)
→ WrapStyler
-
Sets the textDirection.
override
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
variant(Variant variant, WrapStyler style)
→ WrapStyler
-
Must be implemented by the class using this mixin
inherited
-
variants(List<VariantStyle<WrapSpec>> value)
→ WrapStyler
-
Sets the style variants.
override
-
verticalDirection(VerticalDirection value)
→ WrapStyler
-
Sets the verticalDirection.
override
-
wrap(WidgetModifierConfig value)
→ WrapStyler
-
Wraps with a widget modifier.
override
-
wrapAlignment(WrapAlignment value)
→ WrapStyler
-
Sets alignment within each Wrap run.
inherited
-
wrapClipBehavior(Clip value)
→ WrapStyler
-
Sets clipping for overflowing Wrap content.
inherited
Operators
-
operator ==(Object other)
→ bool
-
Overrides the equality operator to compare based on the properties.
inherited